rib: keep AutoPrefixPropagator log levels symmetric

Change-Id: Iabf254706dba0ea7843495912be4154321a91993
refs: #3524
diff --git a/rib/auto-prefix-propagator.hpp b/rib/auto-prefix-propagator.hpp
index f61b129..bd3ef50 100644
--- a/rib/auto-prefix-propagator.hpp
+++ b/rib/auto-prefix-propagator.hpp
@@ -202,9 +202,9 @@
    * @param retryWaitTime the current wait time before retrying propagation
    */
   void
-  startPropagation(const ndn::nfd::ControlParameters& parameters,
-                   const ndn::nfd::CommandOptions& options,
-                   time::seconds retryWaitTime);
+  advertise(const ndn::nfd::ControlParameters& parameters,
+            const ndn::nfd::CommandOptions& options,
+            time::seconds retryWaitTime);
 
   /**
    * @brief send out the unregistration command to revoke the corresponding propagation.
@@ -214,9 +214,9 @@
    * @param retryWaitTime the current wait time before retrying propagation
    */
   void
-  startRevocation(const ndn::nfd::ControlParameters& parameters,
-                  const ndn::nfd::CommandOptions& options,
-                  time::seconds retryWaitTime);
+  withdraw(const ndn::nfd::ControlParameters& parameters,
+           const ndn::nfd::CommandOptions& options,
+           time::seconds retryWaitTime);
 
   /**
    * @brief invoked when Rib::afterInsertEntry signal is emitted
@@ -301,7 +301,7 @@
    * rib.auto_prefix_propagate.refresh_interval.
    *
    * Otherwise, make a copy of the ControlParameters @p parameters, unset its Cost field, and then
    * invoke startRevocation with this new ControlParameters.
    *
    * @param parameters the ControlParameters used by the registration command for propagation
    * @param options the CommandOptions used by the registration command for propagation
@@ -341,7 +341,7 @@
    *
    * If the PropagatedEntry still exists and is not in PROPAGATE_FAIL state, switch it to
    * PROPAGATING. Then make a copy of the ControlParameters @p parameters, reset its Cost, and
    * invoke startPropagation with this new ControlParameters.
    *
    * @param parameters the ControlParameters used by the unregistration command for revocation
    * @param options the CommandOptions used by the unregistration command for revocation
@@ -301,7 +301,7 @@
    *
    * Otherwise, make a copy of the ControlParameters @p parameters, unset its Cost field, and then
-   * invoke startRevocation with this new ControlParameters.
+   * invoke withdraw with this new ControlParameters.
    *
    * @param parameters the ControlParameters used by the registration command for propagation
@@ -341,7 +341,7 @@
    * If the PropagatedEntry still exists and is not in PROPAGATE_FAIL state, switch it to
    * PROPAGATING. Then make a copy of the ControlParameters @p parameters, reset its Cost, and
-   * invoke startPropagation with this new ControlParameters.
+   * invoke advertise with this new ControlParameters.
    *
    * @param parameters the ControlParameters used by the unregistration command for revocation